{% extends 'base/inclusion_tags/controller_object.html' %}
{% block controller_visit %}
<div class="application-item-box bg-blue view">
<a class="link docker" target="blank" href="http://{{controller.get_generic_domain}}">
  <div class="info-box-icon icon-small">
    {% load staticfiles %}
    {% with "img/freebasics-container-vector.png" as icon_src %}
        <img class="icon-container-freebasics" src="{% static icon_src %}"/>
    {% endwith %}
  </div>
  View
</a>
</div>
{% endblock %}

{% block edit_action %}
    <a class="link" href="{% url 'controllers.freebasics:edit' controller.id %}">
        <span><i class="fa fa-gears info-box-icon icon-small"></i></span>
        Edit
    </a>
{% endblock %}
